@@ -1,7 +1,7 @@
 import yaml
 
 import must_triage.fs as fs
-import must_triage.inspectors.base as base
+from . import base
 
 
 class OCP(base.Inspector):
