@@ -3,7 +3,7 @@ import os
 import re
 
 import must_triage.fs as fs
-import must_triage.inspectors.base as base
+from . import base
 
 
 class OCS(base.Inspector):
